# GNUPLOT 3.6 script for plotting SPECTRUM data files (univariate analysis).
#
# Version: 1.1 (30.08.99)
# Author: Michael Schulz
#         Univ. of Bremen, Dept. of Geosciences (FB 5), Germany
#         Email: mschulz@palmod.uni-bremen.de
# --------------------------------------------------------------------------
# Ŀ
#  Global settings 
# 
#
# change to working directory (NB: use '/' NOT '\' to separate dir's)
# -------------------------------------------------------------------
cd '%datdir%'
#
# set pr = 1 to create a postscript file
# ---------------------------------------
pr = 0
if (pr == 1) set encod; \
             set term postscript portrait enhanced "Helvetica" 12; \
             set output '%filenam%.ps';\
             set size 1.0, 0.5;\
             set origin 0.0, 0.5
#
# max. freq to plot
# ----------------
fmax = %hifreq%
set xr[0:fmax]
#
# x-axis title
# ------------
set xlabel 'Frequency [%timeunit%^{-1}]'
#
# bandwidth, bw position constants
# --------------------------------
bw = %bw%
bw2 = 0.95 * fmax
bw1 = bw2 - bw
#
# confidence interval in decibel
# ------------------------------
confdbhi = %confdbhi%
confdblo = %confdblo%
#
# Ŀ
#  Autospectrum X (linear scale) 
# 
#
set title 'Autospectrum: %xinfo%'
set ylabel 'G_{xx} (f)'
#
# mark bandwidth
# --------------
gxxmax = %gxxmax%
ybw = 0.95 * gxxmax
set arrow from bw1, ybw to bw2, ybw nohead
#
# plot data (incl confidence interval)
# -----------------------------------
plot '%filenam%.px' u 1:2 1, '' u 1:($2-$3) 2, '' u 1:($2+$4) 2
set noarrow
if (pr == 0) pause -1
#
# Ŀ
#  Autospectrum X (db scale) 
# 
#
set title 'Autospectrum: %xinfo%'
set ylabel 'G_{xx} (f) [dB]'
#
# prepare bandwidth and conf. interval plotting
# ---------------------------------------------
gxxdbmax = %gxxdbmax%
y2 = 0.95 * gxxdbmax
ybw = y2 - confdbhi
y1 = ybw + confdblo
mid = 0.5 * (bw2 - bw1) + bw1
#
# plot bandwidth and conf marker
# ------------------------------
set arrow from bw1, ybw to bw2, ybw nohead
set arrow from mid, y1 to mid, ybw nohead
set arrow from mid, y2 to mid, ybw nohead
#
# plot data
# ---------
plot '%filenam%.px' u 1:5
set noarrow
if (pr == 0) pause -1
#
# Ŀ
#  Autospectrum Y (linear scale) 
# 
#
set title 'Autospectrum: %yinfo%'
set ylabel 'G_{yy} (f)'
#
# mark bandwidth
# --------------
gyymax = %gyymax%
ybw = 0.95 * gyymax
set arrow from bw1, ybw to bw2, ybw nohead
#
# plot data (incl confidence interval)
# -----------------------------------
plot '%filenam%.py' u 1:2 1, '' u 1:($2-$3) 2, '' u 1:($2+$4) 2
set noarrow
if (pr == 0) pause -1
#
# Ŀ
#  Autospectrum Y (db scale) 
# 
#
set title 'Autospectrum: %yinfo%'
set ylabel 'G_{yy} (f) [dB]'
#
# prepare bandwidth and conf. interval plotting
# ---------------------------------------------
gyydbmax = %gyydbmax%
y2 = 0.95 * gyydbmax
ybw = y2 - confdbhi
y1 = ybw + confdblo
mid = 0.5 * (bw2 - bw1) + bw1
#
# plot bandwidth and conf marker
# ------------------------------
set arrow from bw1, ybw to bw2, ybw nohead
set arrow from mid, y1 to mid, ybw nohead
set arrow from mid, y2 to mid, ybw nohead
#
# plot data
# ---------
plot '%filenam%.py' u 1:5
set noarrow
if (pr == 0) pause -1
#
# Ŀ
#  Cross-Spectrum (linear scale) 
# 
#
set title 'Cross-Spectrum: %xyinfo%'
set ylabel 'G_{xy} (f)'
#
# mark bandwidth
# --------------
gxymax = %gxymax%
ybw = 0.95 * gxymax
set arrow from bw1, ybw to bw2, ybw nohead
#
# plot data
# ---------
plot '%filenam%.pxy' u 1:2
set noarrow
if (pr == 0) pause -1
#
# Ŀ
#  Cross-Spectrum (db scale) 
# 
#
set title 'Cross-Spectrum: %xyinfo%'
set ylabel 'G_{xy} (f) [dB]'
#
# prepare bandwidth and conf. interval plotting
# ---------------------------------------------
gxydbmax = %gxydbmax%
ybw = 0.95 * gxydbmax
#
# plot bandwidth
# --------------
set arrow from bw1, ybw to bw2, ybw nohead
#
# plot data
# ---------
plot '%filenam%.pxy' u 1:3
set noarrow
if (pr == 0) pause -1
#
# Ŀ
#  Coherency-Spectrum X/Y 
# 
#
set title 'Coherency-Spectrum: %xyinfo%'
set ylabel 'c@^2_{xy} (f)'
set yr[0:1.1]
#
# mark bandwidth
# --------------
cxymax = 1.1
ybw = 0.95 * cxymax
set arrow from bw1, ybw to bw2, ybw nohead
#
# plot data (incl confidence interval, and false alarm level)
# -----------------------------------------------------------
plot '%filenam%.cxy' u 1:2 1, \
              '' u 1:($3<0 ? 1/0 : ($2-$3)) 2, \
              '' u 1:($4<0 ? 1/0 : ($2+$4)) 2, \
              '' u 1:5 2
set noarrow
if (pr == 0) pause -1
#
# Ŀ
#  Phase-Spectrum X/Y 
# 
#
set title 'Phase-Spectrum: %xyinfo%'
set ylabel '{/Symbol f}_{xy} (f)'
set yr[-200:200]
#
# mark bandwidth
# --------------
cxymax = 200
ybw = 0.95 * cxymax
set arrow from bw1, ybw to bw2, ybw nohead
#
# plot data (incl confidence interval if delta < 50)
# ---------------------------------------------------
plot '%filenam%.phi' u 1:2, \
                  '' u 1:2:($3<50 ? $3 : 1/0) with yerrorbars,\
                  '' u 1:($3>50 ? $2 : 1/0) with points 1
set noarrow
