# GNUPLOT 3.6 script for plotting SPECTRUM data files (univariate analysis).
#
# Version: 1.1 (30.08.99)
# Author: Michael Schulz
#         Univ. of Bremen, Dept. of Geosciences (FB 5), Germany
#         Email: mschulz@palmod.uni-bremen.de
# --------------------------------------------------------------------------
# Ŀ
#  Global settings 
# 
#
# change to working directory (NB: use '/' NOT '\' to separate dir's)
# -------------------------------------------------------------------
cd '%datdir%'
#
# set pr = 1 to create a postscript file
# ---------------------------------------
pr = 0
if (pr == 1) set encod; \
             set term postscript portrait enhanced "Helvetica" 12; \
             set output '%filenam%.ps';\
             set size 1.0, 0.5;\
             set origin 0.0, 0.5
#
# max freq to plot
# ----------------
fmax = %hifreq%
set xr[0:fmax]
#
# titles
# ------
set title 'Autospectrum: %xinfo%'
set xlabel 'Frequency [%timeunit%^{-1}]'
#
# bandwidth, bw position constants
# --------------------------------
bw = %bw%
bw2 = 0.95 * fmax
bw1 = bw2 - bw
#
# confidence interval in decibel
# ------------------------------
confdbhi = %confdbhi%
confdblo = %confdblo%
#
# Ŀ
#  Autospectrum (linear scale) 
# 
#
set ylabel 'G_{xx} (f)'
#
# mark bandwidth
# --------------
gxxmax = %gxxmax%
ybw = 0.95 * gxxmax
set arrow from bw1, ybw to bw2, ybw nohead
#
# plot data (incl confidence interval)
# -----------------------------------
plot '%filenam%.px' u 1:2 1, '' u 1:($2-$3) 2, '' u 1:($2+$4) 2
set noarrow
if (pr == 0) pause -1
#
# Ŀ
#  Autospectrum (db scale) 
# 
#
set ylabel 'G_{xx} (f) [dB]'
#
# prepare bandwidth and conf. interval plotting
# ---------------------------------------------
gxxmax = %gxxdbmax%
y2 = 0.95 * gxxmax
ybw = y2 - confdbhi
y1 = ybw + confdblo
mid = 0.5 * (bw2 - bw1) + bw1
#
# plot bandwidth and conf marker
# ------------------------------
set arrow from bw1, ybw to bw2, ybw nohead
set arrow from mid, y1 to mid, ybw nohead
set arrow from mid, y2 to mid, ybw nohead
#
# plot data
# ---------
plot '%filenam%.px' u 1:5
set noarrow
